Changelog
=========

1.99.7
------
 - updated paragraph add form renderer
 - updated header logo getter
 - updated content publication support views
 - added property to search filters to hide results count
 - extended sitemap, SEO settings and "robots.txt" view
 - added OpenGraph metas support
 - updated internal and external links pictograms to match TinyMCE editor
 - updated canonical URL support in navigation menus and internal sites links

1.99.6
------
 - added filter add and edit forms title adapters
 - updated viewlet manager interface in tables views
 - updated deprecated Python imports
 - updated filters add menus labels

1.99.5.1
--------
 - corrected error in I18n translation domain

1.99.5
------
 - added aggregated filters support
 - many internal updates

1.99.4
------
 - removed arguments override in thesaurus handlers components

1.99.3
------
 - updated shared content header viewlet to add button to go back to dashboard
 - added status to scheduler tasks execution result
 - added support for direct content retiring or archiving for managers
 - added support for custom modal content class

1.99.2
------
 - added permission and role to manage references tables
 - disable cache when using aggregated search results portlet renderer
 - always open switcher in associations paragraph
 - added method to paragraphs container to get iterator over paragraphs matching a given set of factories
 - removed required flag on gallery files author
 - updated menus order
 - formatting and other minor updates

1.99.1
------
 - added edit forms content getters
 - added alerts types
 - added vocabulary to handle shared contents which can be used by views and search folders
 - minor updates

1.99.0
------
 - first preliminary release
